@@ -168,6 +168,7 @@ type Config struct {
 	remove          removeCmdConfig
 	secret          secretCmdConfig
 	state           stateCmdConfig
+	unmanaged       unmanagedCmdConfig
 	upgrade         upgradeCmdConfig
 
 	// Version information.
@@ -307,7 +308,8 @@ func newConfig(options ...configOption) (*Config, error) {
 			recurseSubmodules: true,
 		},
 		managed: managedCmdConfig{
-			filter: chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
+			filter:    chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
+			pathStyle: pathStyleRelative,
 		},
 		mergeAll: mergeAllCmdConfig{
 			recursive: true,
@@ -315,6 +317,9 @@ func newConfig(options ...configOption) (*Config, error) {
 		reAdd: reAddCmdConfig{
 			filter: chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
 		},
+		unmanaged: unmanagedCmdConfig{
+			pathStyle: pathStyleRelative,
+		},
 		upgrade: upgradeCmdConfig{
 			owner: gitHubOwner,
 			repo:  gitHubRepo,
@@ -369,6 +374,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"lastpass":                 c.lastpassTemplateFunc,
 		"lastpassRaw":              c.lastpassRawTemplateFunc,
 		"lookPath":                 c.lookPathTemplateFunc,
+		"lstat":                    c.lstatTemplateFunc,
 		"mozillaInstallHash":       c.mozillaInstallHashTemplateFunc,
 		"onepassword":              c.onepasswordTemplateFunc,
 		"onepasswordDetailsFields": c.onepasswordDetailsFieldsTemplateFunc,
